@@ -2,8 +2,10 @@
 evaluating arbitrary order Lagrange and many other elements.
 Simplices in one, two, and three dimensions are supported."""
 
+__version__ = "0.9.9"
+
 # Version number
-FIAT_VERSION = "0.9.2"
+FIAT_VERSION = __version__
 
 # Import finite element classes
 from FIAT.argyris import Argyris
@@ -14,22 +16,26 @@ from FIAT.hermite import CubicHermite
 from FIAT.lagrange import Lagrange
 from FIAT.morley import Morley
 from FIAT.nedelec import Nedelec
+from FIAT.nedelec_second_kind import NedelecSecondKind
 from FIAT.P0 import P0
 from FIAT.raviart_thomas import RaviartThomas
 from FIAT.crouzeix_raviart import CrouzeixRaviart
 
 # List of supported elements and mapping to element classes
-element_classes = {"Argyris":                  Argyris,
-                   "Quintic Argyris":          QuinticArgyris,
-                   "Brezzi-Douglas-Marini":    BrezziDouglasMarini,
-                   "Discontinuous Lagrange":   DiscontinuousLagrange,
-                   "Cubic Hermite":            CubicHermite,
-                   "Lagrange":                 Lagrange,
-                   "Morley":                   Morley,
-                   "Nedelec 1st kind H(curl)": Nedelec,
-                   "P0":                       P0,
-                   "Raviart-Thomas":           RaviartThomas,
-                   "Crouzeix-Raviart":         CrouzeixRaviart}
+supported_elements = {"Argyris":                  Argyris,
+                      "Brezzi-Douglas-Marini":    BrezziDouglasMarini,
+                      "Crouzeix-Raviart":         CrouzeixRaviart,
+                      "Discontinuous Lagrange":   DiscontinuousLagrange,
+                      "Hermite":                  CubicHermite,
+                      "Lagrange":                 Lagrange,
+                      "Morley":                   Morley,
+                      "Nedelec 1st kind H(curl)": Nedelec,
+                      "Nedelec 2nd kind H(curl)": NedelecSecondKind,
+                      "Raviart-Thomas":           RaviartThomas}
+
+# List of extra elements
+extra_elements = {"P0":              P0,
+                  "Quintic Argyris": QuinticArgyris}
 
 # Important functionality
 from quadrature import make_quadrature
